@@ -441,10 +441,9 @@ class SystemClient(object):
         if system_display:
             metadata["system_display_name"] = system_display
 
+        # Don't check namespace - https://github.com/beer-garden/beer-garden/issues/827
         if command is None:
             raise ValidationError("Unable to send a request with no command")
-        if system_namespace is None:
-            raise ValidationError("Unable to send a request with no system namespace")
         if system_name is None:
             raise ValidationError("Unable to send a request with no system name")
         if system_version is None:
@@ -465,12 +464,16 @@ class SystemClient(object):
             parameters=kwargs,
         )
 
-        file_params = self._commands[command].parameter_keys_by_type("Base64")
-        resolver = UploadResolver(request, file_params, self._resolvers)
-        request.parameters = resolver.resolve_parameters()
+        request.parameters = self._resolve_parameters(command, request)
 
         return request
 
+    def _resolve_parameters(self, command, request):
+        file_params = self._commands[command].parameter_keys_by_type("Base64")
+        resolver = UploadResolver(request, file_params, self._resolvers)
+
+        return resolver.resolve_parameters()
+
     @staticmethod
     def _determine_latest(systems):
         return (
