@@ -17,6 +17,9 @@ __all__ = [
     "ParameterSchema",
     "RequestSchema",
     "RequestFileSchema",
+    "FileSchema",
+    "FileChunkSchema",
+    "FileStatusSchema",
     "PatchSchema",
     "LoggingConfigSchema",
     "EventSchema",
@@ -216,6 +219,53 @@ class SystemSchema(BaseSchema):
 class RequestFileSchema(BaseSchema):
     storage_type = fields.Str(allow_none=True)
     filename = fields.Str(allow_none=True)
+    id = fields.Str(allow_none=False)
+
+
+class FileSchema(BaseSchema):
+    id = fields.Str(allow_none=True)
+    owner_id = fields.Str(allow_none=True)
+    owner_type = fields.Str(allow_none=True)
+    owner = fields.Raw(allow_none=True)
+    updated_at = DateTime(allow_none=True, format="epoch", example="1500065932000")
+    file_name = fields.Str(allow_none=True)
+    file_size = fields.Int(allow_none=False)
+    chunks = fields.Dict(allow_none=True)
+    chunk_size = fields.Int(allow_none=False)
+
+
+class FileChunkSchema(BaseSchema):
+    id = fields.Str(allow_none=True)
+    file_id = fields.Str(allow_none=False)
+    owner = fields.Raw(allow_none=True)
+    offset = fields.Int(allow_none=False)
+    data = fields.Str(allow_none=False)
+
+
+class FileStatusSchema(BaseSchema):
+    # Top-level file info
+    file_id = fields.Str(allow_none=True)
+    updated_at = fields.Str(allow_none=True)
+    file_name = fields.Str(allow_none=True)
+    file_size = fields.Int(allow_none=True)
+    chunk_size = fields.Int(allow_none=True)
+    chunks = fields.Dict(allow_none=True)
+    owner_id = fields.Str(allow_none=True)
+    owner_type = fields.Str(allow_none=True)
+    # Chunk info
+    chunk_id = fields.Str(allow_none=True)
+    offset = fields.Int(allow_none=True)
+    data = fields.Str(allow_none=True)
+    # Validation metadata
+    valid = fields.Bool(allow_none=True)
+    missing_chunks = fields.List(fields.Int(), allow_none=True)
+    expected_number_of_chunks = fields.Int(allow_none=True)
+    expected_max_size = fields.Int(allow_none=True)
+    number_of_chunks = fields.Int(allow_none=True)
+    size_ok = fields.Bool(allow_none=True)
+    chunks_ok = fields.Bool(allow_none=True)
+    operation_complete = fields.Bool(allow_none=True)
+    message = fields.Str(allow_none=True)
 
 
 class RequestTemplateSchema(BaseSchema):
@@ -427,6 +477,16 @@ class OperationSchema(BaseSchema):
     operation_type = fields.Str(allow_none=True)
 
 
+class RunnerSchema(BaseSchema):
+    id = fields.Str(allow_none=True)
+    name = fields.Str(allow_none=True)
+    path = fields.Str(allow_none=True)
+    instance_id = fields.Str(allow_none=True)
+    stopped = fields.Boolean(allow_none=True)
+    dead = fields.Boolean(allow_none=True)
+    restart = fields.Boolean(allow_none=True)
+
+
 model_schema_map.update(
     {
         "Choices": ChoicesSchema,
@@ -447,10 +507,14 @@ model_schema_map.update(
         "RefreshToken": RefreshTokenSchema,
         "Request": RequestSchema,
         "RequestFile": RequestFileSchema,
+        "File": FileSchema,
+        "FileChunk": FileChunkSchema,
+        "FileStatus": FileStatusSchema,
         "RequestTemplate": RequestTemplateSchema,
         "Role": RoleSchema,
         "System": SystemSchema,
         "Operation": OperationSchema,
+        "Runner": RunnerSchema,
         # Compatibility for the Job trigger types
         "interval": IntervalTriggerSchema,
         "date": DateTriggerSchema,
